package com.ruoyi.bst.userApp.service;

import com.ruoyi.bst.userApp.domain.UserApp;
import com.ruoyi.bst.userApp.domain.UserAppQuery;
import com.ruoyi.bst.userApp.domain.UserAppVO;

import java.util.List;

/**
 * 用户APP关联Service接口
 *
 * @author ruoyi
 * @date 2025-03-14
 */
public interface UserAppService
{
    /**
     * 查询用户APP关联
     *
     * @param id 用户APP关联主键
     * @return 用户APP关联
     */
    public UserAppVO selectUserAppById(Long id);

    /**
     * 查询用户APP关联列表
     *
     * @param userApp 用户APP关联
     * @return 用户APP关联集合
     */
    public List<UserAppVO> selectUserAppList(UserAppQuery userApp);

    /**
     * 新增用户APP关联
     *
     * @param userApp 用户APP关联
     * @return 结果
     */
    public int insertUserApp(UserApp userApp);

    /**
     * 修改用户APP关联
     *
     * @param userApp 用户APP关联
     * @return 结果
     */
    public int updateUserApp(UserApp userApp);

    /**
     * 批量删除用户APP关联
     *
     * @param ids 需要删除的用户APP关联主键集合
     * @return 结果
     */
    public int deleteUserAppByIds(Long[] ids);

    /**
     * 删除用户APP关联信息
     *
     * @param id 用户APP关联主键
     * @return 结果
     */
    public int deleteUserAppById(Long id);


    /**
     * 绑定用户APP
     *
     * @param userId 用户ID
     * @param appId 应用ID
     * @param openId 开放平台ID
     * @return 结果
     */
    public int bind(Long userId, Long appId, String openId);

    /**
     * 查询用户应用信息
     *
     * @param userId 用户ID
     * @param appId 应用ID
     * @return 结果
     */
    public UserAppVO selectByUserApp(Long userId, Long appId);
}
